@@ -11,6 +11,7 @@
 #include "jammo-track-view.h"
 #include "jammo-sample-button.h"
 #include "../meam/jammo-sample.h"
+#include "jammo-mentor.h"
 
 G_DEFINE_TYPE(JammoTrackView, jammo_track_view, TANGLE_TYPE_DROPPABLE_ACTOR);
 
@@ -445,6 +446,9 @@ static void on_actor_added(TangleWidget* widget, ClutterActor* actor, gpointer u
 	sample_button = JAMMO_SAMPLE_BUTTON(actor);
 	sample = jammo_sample_button_get_sample(sample_button);
 	
+	//If user makes first dragging, not clicking, we do not want hear click-message anymore
+	jammo_mentor_speak_once(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_composing_first_click_fi.ogg");
+	jammo_mentor_speak_once(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_composing_first_drag_fi.ogg");
 	if (!jammo_sample_get_editing_track(sample)) {
 		jammo_editing_track_add_sample(track_view->priv->track, jammo_sample_button_get_sample(sample_button),
 	                        	       clutter_actor_get_x(actor) / track_view->priv->real_slot_size * track_view->priv->slot_duration);
@@ -522,7 +526,7 @@ static void move_others_right_if_overlapping(JammoTrackView* track_view, Clutter
 					tangle_signal_connect_vault(animation, "completed", G_CALLBACK(on_animation_completed), vault);
 				} else {
 					jammo_editing_track_add_sample(track_view->priv->track, jammo_sample_button_get_sample(JAMMO_SAMPLE_BUTTON(actor)),
-					                               x * track_view->priv->slot_duration);
+					                               x / track_view->priv->real_slot_size * track_view->priv->slot_duration);
 				}
 			}
 		}
